from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class AuthorizationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = ...) -> None: ...
    def delete_authorizations_id(self, auth_id, **kwargs): ...
    def delete_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def delete_authorizations_id_async(self, auth_id, **kwargs): ...
    def get_authorizations(self, **kwargs): ...
    def get_authorizations_with_http_info(self, **kwargs): ...
    async def get_authorizations_async(self, **kwargs): ...
    def get_authorizations_id(self, auth_id, **kwargs): ...
    def get_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def get_authorizations_id_async(self, auth_id, **kwargs): ...
    def patch_authorizations_id(self, auth_id, authorization_update_request, **kwargs): ...
    def patch_authorizations_id_with_http_info(self, auth_id, authorization_update_request, **kwargs): ...
    async def patch_authorizations_id_async(self, auth_id, authorization_update_request, **kwargs): ...
    def post_authorizations(self, authorization_post_request, **kwargs): ...
    def post_authorizations_with_http_info(self, authorization_post_request, **kwargs): ...
    async def post_authorizations_async(self, authorization_post_request, **kwargs): ...
