from _typeshed import Incomplete

class RestoredBucketMappings:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, id: Incomplete | None = ..., name: Incomplete | None = ..., shard_mappings: Incomplete | None = ...
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def shard_mappings(self): ...
    @shard_mappings.setter
    def shard_mappings(self, shard_mappings) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
