from _typeshed import Incomplete

class CellLinks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, _self: Incomplete | None = ..., view: Incomplete | None = ...) -> None: ...
    @property
    def view(self): ...
    @view.setter
    def view(self, view) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
