from _typeshed import Incomplete

class Replications:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, replications: Incomplete | None = ...) -> None: ...
    @property
    def replications(self): ...
    @replications.setter
    def replications(self, replications) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
